==> maradns_0.9.15.orig.tar.gz: maradns-0.9.15/tuzona/getzone_de.h <==
#define L_FATAL_COMMENT "# Fataler Fehler: "
#define L_TIMEOUT "Verbindungs Time out"
#define L_USAGE "Benutzung: getzone zone_name zone_server_IP"
#define L_VALID_IP "Bitte benutzen Sie eine gueltige IP fuer den Zonen Server"
#define L_NO_SOCK "Kann keinen TCP Socket erstellen"
#define L_NO_CONNECT "Kann keine Verbindung zum Zone Server herstellen"
#define L_NO_SEND "Kann kein send string Objekt erstellen"
#define L_NO_HEADER "Kann keinen DNS Header erstellen"
#define L_NO_ZSTRING "Kann kein zone string Objekt erstellen"
#define L_QSTR2JS_ERROR "qstr2js"
#define L_APPEND_Z "Kann Zonen String an Zonen Objekt anhaengen"
#define L_APPEND_D "Kann keine Punkt an das Ende des zone string Objekt ergaenzen"
#define L_INVALID_NAME "Ungueltige Form eines Zonen Namen"
#define L_APPEND_ZS "Kann zone string nicht an send string anhaengen"
#define L_ADD_QT "Kann Query Type zum Senden nicht ergaenzen"
#define L_ADD_QC "Kann Query Klasse zum Senden nicht ergaenzen"
#define L_SEND_2BYTE "Konnte keinen 2 byte Laengen Header zum Zonen Server senden"
#define L_SEND_QUERY "Konnte keine Anfrage zum Zonen Server senden"
#define L_C_RRNAME "Kontte keine rr.name erzeugen"
#define L_MNAME "Konnte keinen soa.mname erzeugen"
#define L_RNAME "Konnte keinen soa.rname erzeugen"
#define L_NOT_MANLY "Antworten des Server ist nicht lang genug um den Header zu behalten"
#define L_NO_GET "Kann keine Speicher zum Empfang fuer eine String bereitstellen"
#define L_NO_EXPAND "Kann keine Speicher zum Expandieren eines String bereitstellen"
#define L_SERVER "Kann kein Packet vom Server erhalten"
#define L_DECOMPRESS "Fataler Fehler beim durchfuehren der Dekomprimierung"
#define L_RHEADER "Konnte den Header vom Server nicht lesen"
#define L_FORMAT "Format Fehler"
#define L_SERVER_FAIL "Server Fehler""
#define L_NAME "Namens Fehler"
#define L_NOTIMPL "Nicht implementiert"
#define L_REFUSE "Abgelehtn"
#define L_RCODE "Rcode > 5"
#define L_DLABEL "Ungueltiges dlabel in der Anfrage"
#define L_READ_RR_H "Fataler Fehler beim Ausfuehren von read_rr_h"
#define L_GET_S "Konnte nicht get string durchfuehren"
#define L_GET_COPY "Fataler Fehler beim Kopieren vom Namen zum get"
#define L_BALIWICK "# Unterdrueckter out-of-bailiwick Eintrag folgt"
#define L_HASH "# "
#define L_CGET "Konnte keine get string durchfuehren"
#define L_RDDATA "Problem beim Empfang von rddata"
#define L_TRANS "Problem beim Uebersetzen des A record Namen"
#define LF "\n"
#define L_HNAME "Hname problem"
#define L_ZERO "Kein 0-length Name!"

==> maradns_1.0.35.orig.tar.gz: maradns-1.0.35/tuzona/getzone_de.h <==
#define L_FATAL_COMMENT "# Fataler Fehler: "
#define L_TIMEOUT "Verbindungs Time out"
#define L_USAGE_GZ "Benutzung: getzone zone_name zone_server_IP"
#define L_VALID_IP "Bitte benutzen Sie eine gueltige IP fuer den Zonen Server"
#define L_NO_SOCK "Kann keinen TCP Socket erstellen"
#define L_NO_CONNECT "Kann keine Verbindung zum Zone Server herstellen"
#define L_NO_SEND "Kann kein send string Objekt erstellen"
#define L_NO_HEADER "Kann keinen DNS Header erstellen"
#define L_NO_ZSTRING "Kann kein zone string Objekt erstellen"
#define L_QSTR2JS_ERROR "qstr2js"
#define L_APPEND_Z "Kann Zonen String an Zonen Objekt anhaengen"
#define L_APPEND_D "Kann keine Punkt an das Ende des zone string Objekt ergaenzen"
#define L_INVALID_NAME "Ungueltige Form eines Zonen Namen"
#define L_APPEND_ZS "Kann zone string nicht an send string anhaengen"
#define L_ADD_QT "Kann Query Type zum Senden nicht ergaenzen"
#define L_ADD_QC "Kann Query Klasse zum Senden nicht ergaenzen"
#define L_SEND_2BYTE "Konnte keinen 2 byte Laengen Header zum Zonen Server senden"
#define L_SEND_QUERY "Konnte keine Anfrage zum Zonen Server senden"
#define L_C_RRNAME "Kontte keine rr.name erzeugen"
#define L_MNAME "Konnte keinen soa.mname erzeugen"
#define L_RNAME_GZ "Konnte keinen soa.rname erzeugen"
#define L_NOT_MANLY "Antworten des Server ist nicht lang genug um den Header zu behalten"
#define L_NO_GET "Kann keine Speicher zum Empfang fuer eine String bereitstellen"
#define L_NO_EXPAND "Kann keine Speicher zum Expandieren eines String bereitstellen"
#define L_SERVER "Kann kein Packet vom Server erhalten"
#define L_DECOMPRESS "Fataler Fehler beim durchfuehren der Dekomprimierung"
#define L_RHEADER "Konnte den Header vom Server nicht lesen"
#define L_FORMAT "Format Fehler"
#define L_SERVER_FAIL "Server Fehler"
#define L_NAME "Namens Fehler"
#define L_NOTIMPL "Nicht implementiert"
#define L_REFUSE "Abgelehtn"
#define L_RCODE "Rcode > 5"
#define L_DLABEL "Ungueltiges dlabel in der Anfrage"
#define L_READ_RR_H "Fataler Fehler beim Ausfuehren von read_rr_h"
#define L_GET_S "Konnte nicht get string durchfuehren"
#define L_GET_COPY "Fataler Fehler beim Kopieren vom Namen zum get"
#define L_BALIWICK "# Unterdrueckter out-of-bailiwick Eintrag folgt"
#define L_HASH "# "
#define L_CGET "Konnte keine get string durchfuehren"
#define L_RDDATA "Problem beim Empfang von rddata"
#define L_TRANS "Problem beim Uebersetzen des A record Namen"
#define LF "\n"
#define L_HNAME "Hname problem"
#define L_ZERO "Kein 0-length Name!"
